@@ -1820,13 +1820,11 @@ void checkInteraction();
 void stackPreDefinedCommonArrays(char          mode,
                                  Node      ****nodeMembership,
                                  Terminal  ****tTermMembership,
-                                 Node      ****tNodeList,
                                  Terminal  ****tTermList,
                                  Node       ***root);
 void unstackPreDefinedCommonArrays(char          mode,
                                    Node      ***nodeMembership,
                                    Terminal  ***tTermMembership,
-                                   Node      ***tNodeList,
                                    Terminal  ***tTermList,
                                    Node       **root);
 void stackPreDefinedGrowthArrays();
@@ -2062,7 +2060,7 @@ SEXP rfsrcGrow(SEXP traceFlag,
                SEXP nodeDepth,
                SEXP crWeightSize,
                SEXP crWeight,
-               SEXP chunkify,
+               SEXP vimpThreshold,
                SEXP ntree,
                SEXP observationSize,
                SEXP yInfo,
@@ -2085,7 +2083,7 @@ SEXP rfsrcPredict(SEXP traceFlag,
                   SEXP seedPtr,
                   SEXP optLow,
                   SEXP optHigh,
-                  SEXP chunkify,
+                  SEXP vimpThreshold,
                   SEXP ntree,
                   SEXP observationSize,
                   SEXP yInfo,
